# Generated by roxygen2: do not edit by hand

S3method(format,gb_appraisal)
S3method(print,gb_appraisal)
S3method(print,gb_comparison)
S3method(print,gb_economic_case)
S3method(print,gb_headline)
S3method(print,gb_place_based)
S3method(print,gb_progression)
S3method(print,gb_risk_register)
S3method(print,gb_sensitivity_ob)
S3method(print,gb_validation)
S3method(summary,gb_appraisal)
S3method(summary,gb_comparison)
export(gb_apply_ob)
export(gb_appraise)
export(gb_carbon_npv)
export(gb_carbon_value)
export(gb_categories)
export(gb_compare)
export(gb_cost_per_unit)
export(gb_data_versions)
export(gb_deflator)
export(gb_discount)
export(gb_discount_factor)
export(gb_dist_weight)
export(gb_dist_weighted_npv)
export(gb_eanc)
export(gb_economic_case)
export(gb_headline)
export(gb_metb)
export(gb_npv)
export(gb_optimism_bias)
export(gb_place_based)
export(gb_progression)
export(gb_qaly)
export(gb_real)
export(gb_rebase)
export(gb_risk_register)
export(gb_schedule_table)
export(gb_sensitivity_ob)
export(gb_stpr)
export(gb_to_excel)
export(gb_to_latex)
export(gb_to_word)
export(gb_validate)
export(gb_vpf)
export(gb_wellby)
importFrom(cli,cli_abort)
importFrom(cli,cli_h1)
importFrom(cli,cli_inform)
importFrom(cli,cli_text)
importFrom(cli,cli_warn)
importFrom(stats,median)
importFrom(utils,read.csv)
