% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/deflator.R
\name{gb_rebase}
\alias{gb_rebase}
\title{Rebase a real-terms series to a different base year}
\usage{
gb_rebase(values, from, to)
}
\arguments{
\item{values}{Numeric vector of real-terms values.}

\item{from}{Integer base year of the input series.}

\item{to}{Integer target base year.}
}
\value{
A numeric vector of values in \code{to}-year real prices.
}
\description{
Multiplies values currently in \code{from}-year real prices by the
deflator factor to express them in \code{to}-year real prices.
}
\examples{
gb_rebase(c(100, 200, 300), from = 2020, to = 2024)
}
\references{
HM Treasury (2022). The Green Book, chapter on real
terms and price-base alignment.
}
\seealso{
\code{\link[=gb_deflator]{gb_deflator()}}, \code{\link[=gb_real]{gb_real()}}.

Other deflator: 
\code{\link{gb_deflator}()},
\code{\link{gb_real}()}
}
\concept{deflator}
