% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/reporting.R
\name{gb_cost_per_unit}
\alias{gb_cost_per_unit}
\title{Cost per unit delivered}
\usage{
gb_cost_per_unit(appraisal, units_delivered, unit = "unit")
}
\arguments{
\item{appraisal}{A \code{gb_appraisal} object.}

\item{units_delivered}{Numeric scalar. The total quantity of the
output being delivered (e.g. QALYs gained, tCO2e abated,
WELLBYs added, jobs created).}

\item{unit}{Character. Label for the unit (used in print).}
}
\value{
Numeric scalar: PV cost / units delivered, in GBP per
unit.
}
\description{
Computes a cost-effectiveness ratio: total real cost (PV) per
unit of monetised or non-monetised output. Standard cross-scheme
comparator used by HM Treasury reviewers.
}
\examples{
app <- gb_appraise(c(100, 0, 0, 0, 0), c(0, 0, 0, 0, 0))
gb_cost_per_unit(app, units_delivered = 50, unit = "QALY")
}
\seealso{
\code{\link[=gb_appraise]{gb_appraise()}}.

Other reporting: 
\code{\link{gb_headline}()},
\code{\link{gb_to_excel}()},
\code{\link{gb_to_latex}()},
\code{\link{gb_to_word}()}
}
\concept{reporting}
